pub fn store_token(
store: &dyn CredentialStore,
slug: &str,
token: &OAuthToken,
) -> Result<(), OAuthError>Expand description
Persist a token bundle to the keyring under service:<slug>.
pub fn store_token(
store: &dyn CredentialStore,
slug: &str,
token: &OAuthToken,
) -> Result<(), OAuthError>Persist a token bundle to the keyring under service:<slug>.